@@ -1,3 +1,5 @@
+from rich import color
+
 class NotMutableTypeError(Exception):
     pass
 
@@ -20,7 +22,7 @@ class BoolError(NotMutableTypeError):
 class TupleError(NotMutableTypeError):
 
     def __init__(self, value) -> None:
-        super().__init__(f"Expected a boolean, got {type(value).__name__}")
+        super().__init__(f"Expected a tuple, got {type(value).__name__}")
 
 class ListError(NotMutableTypeError):
 
@@ -55,4 +57,26 @@ class DictTypeValueError(NotMutableTypeError):
 class DictKeyError(NotMutableTypeError):
 
     def __init__(self, value) -> None:
-        super().__init__(f"KeyError : {value}")
\ No newline at end of file
+        super().__init__(f"KeyError : {value}")
+
+class CallableError(NotMutableTypeError):
+    def __init__(self, value) -> None:
+        super().__init__(f"Expected a callable, got {type(value).__name__}")
+
+class CallableTypeError(NotMutableTypeError):
+
+    def __init__(self, types, func, value, position: int) -> None:
+
+        super().__init__(
+            f"Expected {', '.join([i.__name__ for i in types if i != None])} types in '{func}' function, not {type(value).__name__} for '{value}' param in position {position}")
+
+class CallableKwargsKeyError(NotMutableTypeError):
+
+    def __init__(self, value, keys: list) -> None:
+        super().__init__(f"'{value}' not in a available key in {', '.join(keys)}")
+
+
+class CallableKwargsValueTypeError(NotMutableTypeError):
+
+    def __init__(self, values, value, arg, func) -> None:
+        super().__init__(f"Expected {', '.join([i.__name__ for i in values])}, got {type(value).__name__} for '{arg}' param in '{func.__name__}' function")
\ No newline at end of file
